% Clear MATLAB
clear all; close all;

% Add path to APM libraries
addpath('../apm');

% Select server
server = 'http://xps.apmonitor.com';

% Application
app = 'erbb';

% Clear previous application
apm(server,app,'clear all');

% load model variables and equations
apm_load(server,app,'erbb.apm');

% load data
csv_load(server,app,'erbb.csv');

% imode = 7, switch to sequential simulation
apm_option(server,app,'nlc.imode',7);

% change history horizon from the default of 100
apm_option(server,app,'nlc.hist_hor',200);

% change time units to seconds
apm_option(server,app,'nlc.ctrl_units',1);

% select solver (1=APOPT, 2=BPOPT, 3=IPOPT)
apm_option(server,app,'nlc.solver',1);

% Run APMonitor
apm(server,app,'solve')

% Retrieve solution (creates solution.csv locally)
solution = apm_sol(server,app);

% Extract names
names = solution(1,:);

% Extract values
cc = cell2mat(solution(2:end,:));

% Time is always the first column
time = cc(:,1);

% extract values for trending
index = find(strcmpi('relakt_pp',names));  akt_pp = cc(:,index);
index = find(strcmpi('relerk_pp',names));  erk_pp = cc(:,index);
index = find(strcmpi('relerb1_p',names));  erb1_p = cc(:,index);

% open web-viewer
apm_web(server,app);

% plot results
figure(1)
subplot(2,1,1);
plot(time,akt_pp,'b-');
hold on;
plot(time,erk_pp,'r-');
legend('AKT PP','ERK PP');
ylabel('Relative Value')
subplot(2,1,2);
plot(time,erb1_p,'g-');
ylabel('Relative Value');
legend('ERB1 P');
xlabel('Time (sec)');
